#
# spec file for package graphene
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           graphene
Version:        1.8.0
Release:        lp151.2.2
Summary:        Thin type layer for graphic libraries
License:        MIT
Group:          Development/Languages/C and C++
Url:            http://ebassi.github.io/graphene/
Source:         https://github.com/ebassi/graphene/archive/%{version}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf

BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.43.1
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  pkgconfig(gobject-2.0) >= 2.30.0

%description
The Graphene library provides types and their relative API for affine
matrices, 4×4 matrices, projections, transformations, vectors and
quaternions.

%package -n libgraphene-1_0-0
Summary:        Thin type layer for graphic libraries
Group:          System/Libraries

%description -n libgraphene-1_0-0
When creating graphic libraries you most likely end up dealing with points
and rectangles. If you're particularly unlucky, you may end up dealing
with affine matrices and 2D transformations. If you're writing a graphic
library with 3D transformations, though, you are going to hit the jackpot:
4x4 matrices, projections, transformations, vectors, and quaternions.

This library provides types and their relative API; it does not deal with
windowing system surfaces, drawing, scene graphs, or input. You're
supposed to do that yourself, in your own canvas implementation, which is
the whole point of writing the library in the first place.

%package -n typelib-1_0-Graphene-1_0
Summary:        GObject introspection for libgraphene, a thin type layer for graphic libraries
Group:          System/Libraries

%description -n typelib-1_0-Graphene-1_0
The Graphene library provides types and their relative API for affine
matrices, 4×4 matrices, projections, transformations, vectors and
quaternions.

%package -n libgraphene-devel
Summary:        Development files for libgraphene, a thin type layer for graphic libraries
Group:          Development/Languages/C and C++
Requires:       libgraphene-1_0-0 = %{version}
Requires:       typelib-1_0-Graphene-1_0 = %{version}

%description -n libgraphene-devel
The Graphene library provides types and their relative API for affine
matrices, 4×4 matrices, projections, transformations, vectors and
quaternions.

This subpackage contains the development files for the Graphene library.

%prep
%autosetup

%build
%meson \
	-D gtk_doc=true \
	-D gobject_types=true \
	-D introspection=true \
	-D gcc_vector=true \
	-D sse2=true \
	-D arm-neon=true \
	-D tests=true \
	-D benchmarks=true \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_libdir}/pkgconfig

%check
%meson_test

%post   -n libgraphene-1_0-0 -p /sbin/ldconfig
%postun -n libgraphene-1_0-0 -p /sbin/ldconfig

%files -n libgraphene-1_0-0
%license LICENSE
%{_libdir}/libgraphene-1.0.so.*

%files -n typelib-1_0-Graphene-1_0
%{_libdir}/girepository-1.0/Graphene-1.0.typelib

%files -n libgraphene-devel
%doc %{_datadir}/gtk-doc/html/*
%{_includedir}/graphene-1.0/
%{_prefix}/lib/installed-tests/
%{_libdir}/libgraphene-1.0.so
%{_libdir}/pkgconfig/graphene-1.0.pc
%{_libdir}/pkgconfig/graphene-gobject-1.0.pc
%dir %{_libdir}/graphene-1.0
%dir %{_libdir}/graphene-1.0/include
%{_libdir}/graphene-1.0/include/graphene-config.h
%{_datadir}/gir-1.0/Graphene-1.0.gir
%dir %{_datadir}/installed-tests
%dir %{_datadir}/installed-tests/graphene-1.0
%{_datadir}/installed-tests/graphene-1.0/*

%changelog
* Fri Feb 23 2018 bjorn.lie@gmail.com
- Update to version 1.8.0:
  + No new API, this cycle, but it's time to spin a new stable
    release.
  + The major news for this release is that we dropped the
    Autotools build from the repository; Graphene is now built
    exclusively with Meson.
  + We've added various fixes to the build on macOS, in order to
    maintain compatibility with the old Autotools build.
  + The variables in the pkg-config file that expose the SIMD
    functionality built inside Graphene have been updated, to
    ensure that they can be easily consumed by other projects;
    instead of a single string that needs to be split, we now
    expose boolean variables for all SIMD implementations.
  + We've also improved the ability to use Graphene as a Meson
    sub-project; this allows Meson to check out, build, and depend
    on Graphene when building complex projects, like GTK. This is
    really useful inside CI pipelines, as it minimises the amount
    of separate steps needed when setting up the build.
- Update options passed to meson, following upstream changes:
  gtk_doc=true, gobject_types=true, introspection=true,
  gcc_vector=true, sse2=true, arm-neon=true, tests=true and
  benchmarks=true.
* Thu Feb 22 2018 bjorn.lie@gmail.com
- Update to version 1.6.2:
  + Mostly fixes for the Meson build, to ensure it's a bit more
    idiomatic and conforms to what newer versions of Meson expect
    from a project.
- Do a minor spec clean, use autosetup and license macros.
- Stop exporting LANG=C.UTF-8, fixed upstream.
- Stop exporting i586 conditional SUSE_ASNEEDED=0, fixed upstream.
- Pass explict enable-gtk-doc=true, enable-gobject-types=true,
  enable-introspection=true, enable-gcc-vector=true,
  enable-sse2=true and enable-arm-neon=true to meson, ensure we
  build the features we want.
- Following the above, add gtk-doc BuildRequires and package the
  now built documentation in devel subpackage.
- Stop using sed to ensure we are using python3, fixed upstream.
- Add fdupes BuildRequires and macro, remove duplicate files.
* Wed Nov 29 2017 dimstar@opensuse.org
- Switch to python3:
  + Update the shebang in src/identfilter.py using sed.
  + Replace --identifier-filter-cmd=python in src/meson.build with
  - -identifier-filter-cmd=python3 (using sed).
  + Add python3-base BuildRequires: needed to have the python3
    interpreter present.
* Wed Aug  9 2017 ro@suse.de
- on i586, disable sse2 for the moment, otherwise the package
  fails in the testsuite on the "box" test
* Sat Mar  4 2017 zaitor@opensuse.org
- Update to version 1.6.0:
  + The Meson dependency has been bumped to 0.37.0.
  + Added graphene_frustum_equal() method.
  + Dropped the -Denable-debug option for the Meson build;
    debugging levels are handled through the --buildtype Meson
    option; you can use release to disable all debugging code paths
    when building Graphene.
  + Graphene now automatically builds binaries for Windows (i686
    and x86_64) using Appveyor; you can find the builds attached to
    the release notes.
* Tue Feb 28 2017 dimstar@opensuse.org
- Add baselibs.conf: produce libgraphene-1_0-0-32bit, required by
  gtk4.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 1.5.4:
  + For the time being and after requests from distributors, the
    autotools build environment has been reinstated in Git, though
    Meson is still the preferred build environment; I still expect
    to drop the autotools build in the near future.
  + Graphene now correctly identifies whether the platform has an
    aligned memory allocator.
  + Compatibility fixes for printing int64_t to terminal.
  + Fixed the cross-references to GLib types in the API reference
    build.
  + Improve the builtin detection in the Meson build and the build
    of Graphene under MingW.
- Switch to github url, gnome url is currently broken.
- Pass export LANG=C.UTF-8, workaround meson issue.
- Drop sed call to workaround Mesa issue.
* Tue Dec  6 2016 dimstar@opensuse.org
- Use meson provided macros to build instead of carrying the long
  meson command lines.
* Mon Nov 28 2016 jengelh@inai.de
- Trim description outside the main subpackage of interest;
  reflow summaries.
* Thu Nov 24 2016 dimstar@opensuse.org
- Initial package, version 1.5.2.
